# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# (C) British Crown copyright. The Met Office.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
# * Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
"""Tests for the compare CLI"""

import pytest

from . import acceptance as acc

pytestmark = [pytest.mark.acc, acc.skip_if_kgo_missing]
CLI = acc.cli_name_with_dashes(__file__)
run_cli = acc.run_cli(CLI, verbose=False)


def test_same(capsys):
    """Compare identical files, should not produce any output"""
    kgo_dir = acc.kgo_root()
    input_file = kgo_dir / "wind_downscaling/basic/highres_orog.nc"
    matching_file = kgo_dir / "wind_downscaling/veg/highres_orog.nc"
    args = [input_file, matching_file]
    run_cli(args)
    captured = capsys.readouterr()
    assert captured.out == ""
    assert captured.err == ""


def test_different(capsys):
    """Compare different files, should report differences to stdout"""
    kgo_dir = acc.kgo_root()
    a_file = kgo_dir / "generate-percentiles/basic/input.nc"
    b_file = kgo_dir / "threshold/basic/input.nc"
    args = [a_file, b_file]
    run_cli(args)
    captured = capsys.readouterr()
    assert "different dimension size" in captured.out
    assert "different variables" in captured.out
    assert "different data" in captured.out


def test_ignored_attributes(capsys):
    """Ensure attribute differences are not reported if explicity excluded."""
    kgo_dir = acc.kgo_root()
    a_file = kgo_dir / "spot-extract/inputs/all_methods_uk_unique_ids.nc"
    b_file = kgo_dir / "spot-extract/inputs/all_methods_global.nc"
    args = [a_file, b_file, "--ignored-attributes=model_grid_hash"]
    run_cli(args)
    captured = capsys.readouterr()
    assert "different attribute value" not in captured.out
